@@ -3,8 +3,8 @@ from enum import Enum
 
 class Symbol(Enum):
     JPY = 'USD_JPY'
-    GBP = 'EUR_USD'
-    EUR = 'GBP_USD'
+    GBP = 'GBP_USD'
+    EUR = 'EUR_USD'
     AUD = 'AUD_USD'
     GOLD = 'XAU_USD'
     BTC = 'BTC_USD'
